/*
 * Copyright (c) 2016-2021 Free Software Foundation, Inc.
 *
 * This file is part of libwget.
 *
 * Libwget is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Libwget is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libwget.  If not, see <https://www.gnu.org/licenses/>.
 *
 *
 * Libwget version information
 */

#ifndef WGET_WGETVER_H
#define WGET_WGETVER_H

#define LIBWGET_VERSION "2.0.0"
#define LIBWGET_VERSION_MAJOR 2
#define LIBWGET_VERSION_MINOR 0
#define LIBWGET_VERSION_PATCH 0
#define LIBWGET_VERSION_NUMBER 0x020000

#endif /* WGET_WGETVER_H */
